Detailed API Documentation
==========================

Documention of the classes and methods provided by **leveldiagram**

.. currentmodule:: leveldiagram

Level Diagram Constructors
--------------------------

.. autoclass:: LD
    :members:
    :undoc-members:
    :private-members:


Artist Primitives
-----------------

.. automodule:: leveldiagram.artists
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: set


Utilities
---------

.. automodule:: leveldiagram.utils
    :members:
    :undoc-members: